==> anjuta_3.4.0.orig.tar.xz: anjuta-3.4.0/plugins/git/git-status-command.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * anjuta
 * Copyright (C) James Liggett 2008 <jrliggett@cox.net>
 * 
 * anjuta is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * anjuta is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with anjuta.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef _GIT_STATUS_COMMAND_H_
#define _GIT_STATUS_COMMAND_H_

#include <glib-object.h>
#include "git-command.h"
#include "git-status.h"

G_BEGIN_DECLS

#define GIT_TYPE_STATUS_COMMAND             (git_status_command_get_type ())
#define GIT_STATUS_COMMAND(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIT_TYPE_STATUS_COMMAND, GitStatusCommand))
#define GIT_STATUS_COMMAND_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GIT_TYPE_STATUS_COMMAND, GitStatusCommandClass))
#define GIT_IS_STATUS_COMMAND(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIT_TYPE_STATUS_COMMAND))
#define GIT_IS_STATUS_COMMAND_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GIT_TYPE_STATUS_COMMAND))
#define GIT_STATUS_COMMAND_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GIT_TYPE_STATUS_COMMAND, GitStatusCommandClass))

typedef struct _GitStatusCommandClass GitStatusCommandClass;
typedef struct _GitStatusCommand GitStatusCommand;
typedef struct _GitStatusCommandPriv GitStatusCommandPriv;

typedef enum
{
	GIT_STATUS_SECTION_COMMIT = 1 << 0,
	GIT_STATUS_SECTION_NOT_UPDATED = 1 << 1,
	GIT_STATUS_SECTION_UNTRACKED = 1 << 2,
	GIT_STATUS_SECTION_MODIFIED = (GIT_STATUS_SECTION_COMMIT | 
								   GIT_STATUS_SECTION_NOT_UPDATED)
} GitStatusSections;

struct _GitStatusCommandClass
{
	GitCommandClass parent_class;
};

struct _GitStatusCommand
{
	GitCommand parent_instance;
	
	GitStatusCommandPriv *priv;
};

GType git_status_command_get_type (void) G_GNUC_CONST;
GitStatusCommand *git_status_command_new (const gchar *working_directory,
										  GitStatusSections sections);
GQueue *git_status_command_get_status_queue (GitStatusCommand *self);

G_END_DECLS

#endif /* _GIT_STATUS_COMMAND_H_ */

==> anjuta_3.34.0.orig.tar.xz: anjuta-3.34.0/plugins/git/git-status-command.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * anjuta
 * Copyright (C) James Liggett 2008 <jrliggett@cox.net>
 * 
 * anjuta is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * anjuta is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with anjuta.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef _GIT_STATUS_COMMAND_H_
#define _GIT_STATUS_COMMAND_H_

#include <glib-object.h>
#include "git-command.h"
#include "git-status-factory.h"

G_BEGIN_DECLS

#define GIT_TYPE_STATUS_COMMAND             (git_status_command_get_type ())
#define GIT_STATUS_COMMAND(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIT_TYPE_STATUS_COMMAND, GitStatusCommand))
#define GIT_STATUS_COMMAND_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GIT_TYPE_STATUS_COMMAND, GitStatusCommandClass))
#define GIT_IS_STATUS_COMMAND(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIT_TYPE_STATUS_COMMAND))
#define GIT_IS_STATUS_COMMAND_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GIT_TYPE_STATUS_COMMAND))
#define GIT_STATUS_COMMAND_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GIT_TYPE_STATUS_COMMAND, GitStatusCommandClass))

typedef struct _GitStatusCommandClass GitStatusCommandClass;
typedef struct _GitStatusCommand GitStatusCommand;
typedef struct _GitStatusCommandPriv GitStatusCommandPriv;

struct _GitStatusCommandClass
{
	GitCommandClass parent_class;
};

struct _GitStatusCommand
{
	GitCommand parent_instance;
	
	GitStatusCommandPriv *priv;
};

GType git_status_command_get_type (void) G_GNUC_CONST;
GitStatusCommand *git_status_command_new (const gchar *working_directory);
GQueue *git_status_command_get_status_queue (GitStatusCommand *self);

G_END_DECLS

#endif /* _GIT_STATUS_COMMAND_H_ */
